@@ -1,49 +1,8 @@
-#############################################################################
-##
-## Copyright (C) 2013 Riverbank Computing Limited.
-## Copyright (C) 2016 The Qt Company Ltd.
-## Contact: http://www.qt.io/licensing/
-##
-## This file is part of the Qt for Python examples of the Qt Toolkit.
-##
-## $QT_BEGIN_LICENSE:BSD$
-## You may use this file under the terms of the BSD license as follows:
-##
-## "Redistribution and use in source and binary forms, with or without
-## modification, are permitted provided that the following conditions are
-## met:
-##   * Redistributions of source code must retain the above copyright
-##     notice, this list of conditions and the following disclaimer.
-##   * Redistributions in binary form must reproduce the above copyright
-##     notice, this list of conditions and the following disclaimer in
-##     the documentation and/or other materials provided with the
-##     distribution.
-##   * Neither the name of The Qt Company Ltd nor the names of its
-##     contributors may be used to endorse or promote products derived
-##     from this software without specific prior written permission.
-##
-##
-## THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-## "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
-## LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
-## A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
-## OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
-## SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-## LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
-## DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
-## THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-## (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
-## OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE."
-##
-## $QT_END_LICENSE$
-##
-#############################################################################
-
-"""PySide2 port of the widgets/mainwindows/dockwidgets example from Qt v5.x, originating from PyQt"""
+"""TeDa FITS Viewer main window"""
 import PySide2
-from PySide2 import QtWidgets
+from PySide2 import QtWidgets, QtCore
 from PySide2.QtCore import QFile, Qt, QTextStream, QSettings
-from PySide2.QtGui import (QFont, QIcon, QKeySequence)
+from PySide2.QtGui import QFont, QIcon, QKeySequence
 from PySide2.QtPrintSupport import QPrintDialog, QPrinter
 from PySide2.QtWidgets import (QAction, QApplication, QLabel, QDialog, QDockWidget, QWidget, QPushButton,
                                QFileDialog, QMainWindow, QMessageBox, QTableWidgetItem,
@@ -56,7 +15,7 @@ from teda.version import __version__
 from teda.views.fitsplot import FitsPlotter
 from teda.views.fitsplot_fitsfile import FitsPlotterFitsFile
 from teda.models.coordinates import CoordinatesModel
-from .painterComponent import PainterComponent
+from teda.painterComponent import PainterComponent
 from teda.widgets.radialprofile import RadialProfileWidget
 from teda.widgets.fullViewWidget import FullViewWidget
 from teda.widgets.zoomViewWidget import ZoomViewWidget
@@ -67,12 +26,14 @@ from teda.widgets.scanToolbar import ScanToolbar
 from teda.widgets.info import InfoWidget
 from teda.models.cmaps import ColorMaps
 from teda.models.scalesModel import ScalesModel
+from teda.icons import IconFactory
 from . import console
 
 
 class MainWindow(QMainWindow):
-    def __init__(self):
+    def __init__(self, tedaCommandLine):
         super().__init__()
+        self.tedaCommandLine = tedaCommandLine
         self.cmaps = ColorMaps()
         self.combobox = QComboBox()
         self.filename = None
@@ -103,15 +64,17 @@ class MainWindow(QMainWindow):
         self.createMenus()
         self.createToolBars()
         self.createStatusBar()
-        self.createInfoWindow()
         self.createDockWindows()
-        self.scaleWidget.readSlidersValues()
+        if not self.tedaCommandLine.ignoreSettings:
+            self.scaleWidget.readSlidersValues()
         # self.defineButtonsActions()
         self.setWindowTitle("TeDa")
 
         self.readWindowSettings()
         self.readAppState()
 
+        self.updateHeaderData()
+
         self.painterComponent.observe(lambda change: self.onCenterCircleChange(change), ['ccenter_x', 'ccenter_y'])
         self.painterComponent.observe(lambda change: self.onCenterCircleRadiusChange(change), ['cradius'])
         self.fits_image.observe(lambda change: self.onMouseMoveOnImage(change), ['mouse_xdata', 'mouse_ydata'])
@@ -130,7 +93,8 @@ class MainWindow(QMainWindow):
     def closeEvent(self, event: PySide2.QtGui.QCloseEvent):
         self.writeAppState()
         self.writeWindowSettings()
-        self.scaleWidget.writeSlidersValues()
+        if not self.tedaCommandLine.ignoreSettings:
+            self.scaleWidget.writeSlidersValues()
         super().closeEvent(event)
 
     def keyPressEvent(self, e):
@@ -158,7 +122,6 @@ class MainWindow(QMainWindow):
 
     def open_dialog(self):
         fileName, _ = QFileDialog.getOpenFileName(self, "Open Image", ".", "Fits files (*.fits)")
-        # fileName = QFileDialog.getOpenFileName(mainWin, "Open Image", "/home/akond/Pulpit/fits files", "Fits files (*.fits)")[0]
         if fileName:
             self.open_fits(fileName)
 
@@ -195,29 +158,37 @@ class MainWindow(QMainWindow):
         self.radial_profile_iraf_widget.set_data(self.fits_image.data)
         # self.scaleWidget.adjustSliders()
 
-        self.headerWidget.setHeader()
+        self.updateHeaderData()
 
         self.zoom_view_widget.updateFits(self.fits_image)
         self.full_view_widget.updateFits(self.fits_image)
         self.saveLastFits()
 
     def saveLastFits(self):
+        if self.tedaCommandLine.ignoreSettings:
+            return
         settings = QSettings()
         settings.beginGroup("Files")
         settings.setValue("lastFile", self.filename)
         settings.endGroup()
 
     def openLastFits(self):
-        settings = QSettings()
-        settings.beginGroup("Files")
-        filename = settings.value("lastFile")
-        settings.endGroup()
+        if (self.tedaCommandLine.openFile is None):
+            if self.tedaCommandLine.ignoreSettings:
+                return
+            settings = QSettings()
+            settings.beginGroup("Files")
+            filename = settings.value("lastFile")
+            settings.endGroup()
+        else:
+            filename = self.tedaCommandLine.openFile
         if filename:
             self.open_fits(filename)
 
     def readAppState(self):
+        if self.tedaCommandLine.ignoreSettings:
+            return
         settings = QSettings()
-
         settings.beginGroup("WCS")
         self.wcsSexAct.setChecked(bool(settings.value("sexagesimal", True)))
         self.wcsGridAct.setChecked(bool(settings.value("grid", False)))
@@ -226,8 +197,9 @@ class MainWindow(QMainWindow):
 
 
     def writeAppState(self):
+        if self.tedaCommandLine.ignoreSettings:
+            return
         settings = QSettings()
-
         settings.beginGroup("WCS")
         settings.setValue("sexagesimal", self.wcsSexAct.isChecked())
         settings.setValue("grid", self.wcsGridAct.isChecked())
@@ -258,7 +230,12 @@ class MainWindow(QMainWindow):
                           "Created by <a href='https://akond.com'>Akond Lab</a> for The Araucaria Project")
 
     def on_console_show(self):
-        console.show(ax=self.fits_image.ax, window=self, data=self.fits_image.data, header=self.fits_image.header, wcs=self.cursor_coords.wcs)
+        console.show(
+            ax=self.fits_image.ax,
+            window=self,
+            data=self.fits_image.data,
+            header=self.fits_image.header,
+            wcs=self.cursor_coords.wcs)
 
     def on_sex_toggle(self):
         print('sex toggled to :', self.wcsSexAct.isChecked())
@@ -270,7 +247,8 @@ class MainWindow(QMainWindow):
     def createActions(self):
         # ico1 = QPixmap('/Users/mka/projects/astro/teda/icons/png.png')
         # self.openAct = QAction(ico1, "&Open", self, shortcut=QKeySequence.Open, statusTip="Open FITS file", triggered=self.open)
-        self.openAct = QAction(QIcon.fromTheme('document-open'), "&Open", self, shortcut=QKeySequence.Open, statusTip="Open FITS file", triggered=self.open_dialog)
+        self.openAct = QAction(IconFactory.getIcon('note_add'),
+                               "&Open", self, shortcut=QKeySequence.Open, statusTip="Open FITS file", triggered=self.open_dialog)
         self.quitAct = QAction("&Quit", self, shortcut="Ctrl+Q", statusTip="Quit the application", triggered=self.close)
         self.aboutAct = QAction("&About", self, statusTip="Show the application's About box", triggered=self.about)
         self.aboutQtAct = QAction("About &Qt", self, statusTip="Show the Qt library's About box", triggered=QApplication.instance().aboutQt)
@@ -288,6 +266,29 @@ class MainWindow(QMainWindow):
         self.wcsGridAct.setCheckable(True)
         self.wcsGridAct.toggled.connect(self.on_grid_toggle)
 
+        self.prevHDUAct = QAction(IconFactory.getIcon('skip_previous'), 'Prev HDU', self,
+                                  statusTip="Previous HDU", triggered=self.prevHDU)
+        self.nextHDUAct = QAction(IconFactory.getIcon('skip_next'), 'Next HDU', self,
+                                  statusTip="Next HDU", triggered=self.nextHDU)
+
+        self.zoom4Act = QAction(IconFactory.getIcon(), '×4', self,
+                                  statusTip="Zoom ×4", triggered=self.setZoomButton4)
+        self.zoom2Act = QAction(IconFactory.getIcon(), '×2', self,
+                                  statusTip="Zoom ×2", triggered=self.setZoomButton2)
+        self.zoomHomeAct = QAction(IconFactory.getIcon('home'), 'Home', self,
+                                  statusTip="Reset zoom an position", triggered=self.setZoomButtonHome)
+        self.zoom05Act = QAction(IconFactory.getIcon(), '1/2', self,
+                                  statusTip="Zoom 1/2", triggered=self.setZoomButton05)
+        self.zoom025Act = QAction(IconFactory.getIcon(), '1/4', self,
+                                  statusTip="Zoom 1/4", triggered=self.setZoomButton025)
+
+        self.circleAct = QAction(IconFactory.getIcon('circle'), 'Add Region', self,
+                                  statusTip="Add Region", triggered=self.changeAddCircleStatus)
+        self.centerCircleAct = QAction(IconFactory.getIcon('add_circle_outline'), 'Radial profile', self,
+                                 statusTip="Radial profile with gaussoide fit [R]-key", triggered=self.changeAddCenterCircleStatus)
+        self.deleteAct = QAction(IconFactory.getIcon('delete_forever'), 'Delete selected', self,
+                                 statusTip="Delete selected [Del]-key", triggered=self.deleteSelected)
+
     def createMenus(self):
         self.fileMenu = self.menuBar().addMenu("&File")
         self.fileMenu.addAction(self.openAct)
@@ -315,58 +316,59 @@ class MainWindow(QMainWindow):
         self.fileToolBar.addAction(self.openAct)
 
         self.hduToolBar = self.addToolBar("HDU Toolbar")
-        self.hduToolBar.addAction("prevHDU").triggered.connect(self.prevHDU)
-        self.hduToolBar.addAction("nextHDU").triggered.connect(self.nextHDU)
+        self.hduToolBar.addAction(self.prevHDUAct)
+        self.hduToolBar.addAction(self.nextHDUAct)
 
         self.scanToolBar = self.addToolBar("Scan Toolbar")
-        self.scanwidget = ScanToolbar(self)
-        self.scanToolBar.addWidget(self.scanwidget)
+        self.scanObject = ScanToolbar(self)
+        self.scanToolBar.addAction(self.scanObject.scanAct)
+        self.scanToolBar.addAction(self.scanObject.stopAct)
+        self.scanToolBar.addAction(self.scanObject.pauseAct)
+        self.scanToolBar.addAction(self.scanObject.resumeAct)
+        self.scanToolBar.hide()
 
-        self.infoToolBar = self.addToolBar("Info Toolbar")
-        self.mouse_x_label = QLabel('100.1')
-        self.mouse_y_label = QLabel('100.145')
-        self.infoToolBar.addWidget(QLabel('image x:'))
-        self.infoToolBar.addWidget(self.mouse_x_label)
-        self.infoToolBar.addWidget(QLabel('y:'))
-        self.infoToolBar.addWidget(self.mouse_y_label)
+        # self.infoToolBar = self.addToolBar("Info Toolbar")
+        # self.mouse_x_label = QLabel('100.1')
+        # self.mouse_y_label = QLabel('100.145')
+        # self.infoToolBar.addWidget(QLabel('image x:'))
+        # self.infoToolBar.addWidget(self.mouse_x_label)
+        # self.infoToolBar.addWidget(QLabel('y:'))
+        # self.infoToolBar.addWidget(self.mouse_y_label)
+        # self.infoToolBar.hide()
 
         self.zoomToolBar = self.addToolBar("Zoom Toolbar")
-        self.zoomToolBar.addAction("x4").triggered.connect(self.setZoomButton4)
-        self.zoomToolBar.addAction("x2").triggered.connect(self.setZoomButton2)
-        self.zoomToolBar.addAction("Home").triggered.connect(self.setZoomButtonHome)
-        self.zoomToolBar.addAction("1/2").triggered.connect(self.setZoomButton05)
-        self.zoomToolBar.addAction("1/4").triggered.connect(self.setZoomButton025)
+        self.zoomToolBar.addAction(self.zoom4Act)
+        self.zoomToolBar.addAction(self.zoom2Act)
+        self.zoomToolBar.addAction(self.zoomHomeAct)
+        self.zoomToolBar.addAction(self.zoom05Act)
+        self.zoomToolBar.addAction(self.zoom025Act)
 
         self.mouseActionToolBar = self.addToolBar("Mouse Task Toolbar")
-
-        self.BtnCircle = QPushButton("Add Region")
-        self.BtnCircle.setCheckable(True)
-        self.BtnCircle.clicked.connect(self.changeAddCircleStatus)
-        self.mouseActionToolBar.addWidget(self.BtnCircle)
-
-        self.BtnCenterCircle = QPushButton("Radial profile")
-        self.BtnCenterCircle.setCheckable(True)
-        self.BtnCenterCircle.clicked.connect(self.changeAddCenterCircleStatus)
-        self.mouseActionToolBar.addWidget(self.BtnCenterCircle)
-
-        self.BtnDelete = QPushButton("Delete selected")
-        self.BtnDelete.clicked.connect(self.deleteSelected)
-        self.mouseActionToolBar.addWidget(self.BtnDelete)
+        self.circleAct.setCheckable(True)
+        self.mouseActionToolBar.addAction(self.circleAct)
+        self.centerCircleAct.setCheckable(True)
+        self.mouseActionToolBar.addAction(self.centerCircleAct)
+        self.mouseActionToolBar.addAction(self.deleteAct)
 
         self.viewMenu.addAction(self.fileToolBar.toggleViewAction())
         self.viewMenu.addAction(self.hduToolBar.toggleViewAction())
         self.viewMenu.addAction(self.scanToolBar.toggleViewAction())
-        self.viewMenu.addAction(self.infoToolBar.toggleViewAction())
+        # self.viewMenu.addAction(self.infoToolBar.toggleViewAction())
         self.viewMenu.addAction(self.mouseActionToolBar.toggleViewAction())
         self.viewMenu.addSeparator()
 
     def nextHDU(self):
         self.fits_image.changeHDU(True, 1)
-        self.headerWidget.setHeader()
+        self.updateHeaderData()
 
     def prevHDU(self):
         self.fits_image.changeHDU(True, -1)
+        self.updateHeaderData()
+
+    def updateHeaderData(self):
         self.headerWidget.setHeader()
+        self.prevHDUAct.setEnabled(self.fits_image._huds is not None and self.fits_image.hdu != 0)
+        self.nextHDUAct.setEnabled(self.fits_image._huds is not None and self.fits_image.hdu != len(self.fits_image._huds) - 1)
 
     def setZoomButton4(self):
         self.setZoomButton(4,False)
@@ -384,18 +386,18 @@ class MainWindow(QMainWindow):
             self.full_view_widget.updateMiniatureShape(self.fits_image.viewX, self.fits_image.viewY, self.fits_image.viewW, self.fits_image.viewH)
 
     def changeAddCircleStatus(self):
-        if self.BtnCircle.isChecked():
+        if self.circleAct.isChecked():
             self.toogleOffRegionButtons()
-            self.BtnCircle.toggle()
+            self.circleAct.toggle()
             self.painterComponent.startPainting(self.central_widget, "circle")
         else:
             self.painterComponent.stopPainting(self.central_widget)
             self.painterComponent.startMovingEvents(self.central_widget)
 
     def changeAddCenterCircleStatus(self):
-        if self.BtnCenterCircle.isChecked():
+        if self.centerCircleAct.isChecked():
             self.toogleOffRegionButtons()
-            self.BtnCenterCircle.toggle()
+            self.centerCircleAct.toggle()
             self.painterComponent.startPainting(self.central_widget,"circleCenter")
         else:
             self.painterComponent.stopPainting(self.central_widget)
@@ -405,10 +407,10 @@ class MainWindow(QMainWindow):
         self.painterComponent.deleteSelectedShapes(self.central_widget.figure.axes[0])
 
     def toogleOffRegionButtons(self):
-        if self.BtnCircle.isChecked():
-            self.BtnCircle.toggle()
-        if self.BtnCenterCircle.isChecked():
-            self.BtnCenterCircle.toggle()
+        if self.circleAct.isChecked():
+            self.circleAct.toggle()
+        if self.centerCircleAct.isChecked():
+            self.centerCircleAct.toggle()
         self.painterComponent.stopPainting(self.central_widget)
 
 
@@ -424,6 +426,9 @@ class MainWindow(QMainWindow):
         dock.setWidget(self.scaleWidget)
         self.addDockWidget(Qt.RightDockWidgetArea, dock)
         self.viewMenu.addAction(dock.toggleViewAction())
+        dock.setFloating(True)
+        dock.hide()
+
 
         #radial profiles
         dock = QDockWidget("Radial Profile Fit", self)
@@ -442,6 +447,7 @@ class MainWindow(QMainWindow):
         dock.setWidget(self.radial_profile_widget)
         self.addDockWidget(Qt.RightDockWidgetArea, dock)
         self.viewMenu.addAction(dock.toggleViewAction())
+        dock.hide()
 
         #info panel
         dock = QDockWidget("Info", self)
@@ -449,9 +455,24 @@ class MainWindow(QMainWindow):
         dock.setAllowedAreas(Qt.LeftDockWidgetArea | Qt.RightDockWidgetArea | Qt.TopDockWidgetArea)
         self.info_widget = InfoWidget(self)
         dock.setWidget(self.info_widget)
-        self.addDockWidget(Qt.RightDockWidgetArea, dock)
+        self.addDockWidget(Qt.TopDockWidgetArea, dock)
         self.viewMenu.addAction(dock.toggleViewAction())
 
+        # FITS headers
+        dock = QDockWidget("FITS header", self)
+        dock.setObjectName("FTIS_DATA")
+        dock.setAllowedAreas(Qt.LeftDockWidgetArea | Qt.RightDockWidgetArea | Qt.TopDockWidgetArea)
+        self.addDockWidget(Qt.TopDockWidgetArea, dock)
+        self.viewMenu.addAction(dock.toggleViewAction())
+        self.headerWidget = HeaderTableWidget(self)
+        self.headerWidget.setColumnCount(2)
+        self.headerWidget.setHorizontalHeaderItem(0, QTableWidgetItem("KEY"))
+        self.headerWidget.setHorizontalHeaderItem(1, QTableWidgetItem("VALUE"))
+        self.headerWidget.horizontalHeader().setStretchLastSection(1)
+        self.headerWidget.setEditTriggers(QtWidgets.QTableWidget.NoEditTriggers)
+        self.headerWidget.clearFocus()
+        dock.setWidget(self.headerWidget)
+
         # full
         dock = QDockWidget("Full view", self)
         dock.setObjectName("FULL_VIEW")
@@ -475,20 +496,6 @@ class MainWindow(QMainWindow):
 
         self.viewMenu.addSeparator()
 
-    def createInfoWindow(self):
-        dock = QDockWidget("FITS header", self)
-        dock.setObjectName("FTIS_DATA")
-        dock.setAllowedAreas(Qt.LeftDockWidgetArea | Qt.RightDockWidgetArea | Qt.TopDockWidgetArea)
-
-        self.addDockWidget(Qt.RightDockWidgetArea, dock)
-        self.viewMenu.addAction(dock.toggleViewAction())
-        self.headerWidget = HeaderTableWidget(self)
-        self.headerWidget.setColumnCount(2)
-        self.headerWidget.setHorizontalHeaderItem(0, QTableWidgetItem("KEY"))
-        self.headerWidget.setHorizontalHeaderItem(1, QTableWidgetItem("VALUE"))
-        self.headerWidget.horizontalHeader().setStretchLastSection(1)
-        self.headerWidget.setEditTriggers(QtWidgets.QTableWidget.NoEditTriggers)
-        dock.setWidget(self.headerWidget)
 
     # def changeColor(self, color):
     #     self.cmaps.set_active_color_map(color)
@@ -554,6 +561,8 @@ class MainWindow(QMainWindow):
             self.full_view_widget.updateMiniatureShape(self.fits_image.viewX,self.fits_image.viewY,self.fits_image.viewW,self.fits_image.viewH)
 
     def readWindowSettings(self):
+        if self.tedaCommandLine.ignoreSettings:
+            return
         settings = QSettings()
         settings.beginGroup("MainWindow")
         size, pos = settings.value("size"), settings.value("pos")
@@ -577,6 +586,8 @@ class MainWindow(QMainWindow):
         self.headerWidget.readSettings(settings)
 
     def writeWindowSettings(self):
+        if self.tedaCommandLine.ignoreSettings:
+            return
         settings = QSettings()
         settings.beginGroup("MainWindow")
         settings.setValue("size", self.size())
